from sqlalchemy import Column, Integer, Boolean, Text, ForeignKey
from .base_model import BaseModel, CreateModel, UpdateModel, DeleteModel


class ExerciseRecordDetailModel(BaseModel, CreateModel, UpdateModel,
                                DeleteModel):
    """
    练习记录详情模型
    对应数据库表: exercise_record_details
    """
    __tablename__ = 'exercise_record_details'

    record_id = Column(Integer,
                       ForeignKey('exercise_records.id'),
                       nullable=False,
                       comment='练习记录ID')
    question_id = Column(Integer,
                         ForeignKey('questions.id'),
                         nullable=False,
                         comment='题目ID')
    selected_option_id = Column(Integer,
                                ForeignKey('question_options.id'),
                                comment='用户选择的选项ID')
    user_answer = Column(Text, comment='用户答案')
    is_correct = Column(Boolean, nullable=False, comment='是否正确')
    time_spent = Column(Integer, nullable=False, comment='用时（秒）')

    def __repr__(self):
        return f"<ExerciseRecordDetail(id={self.id}, record_id={self.record_id}, question_id={self.question_id})>"
