from datetime import datetime
from typing import Optional
from sqlalchemy import Column, Integer, String, DateTime, Boolean, Text
from sqlalchemy.orm import relationship
from .base_model import BaseModel, CreateModel, UpdateModel, DeleteModel


class PermissionModel(BaseModel, CreateModel, UpdateModel, DeleteModel):
    """
    权限模型
    对应数据库表: sys_permissions
    """
    __tablename__ = 'sys_permissions'

    name = Column(String(50), unique=True, nullable=False, comment='权限名称')
    code = Column(String(50), unique=True, nullable=False, comment='权限代码')
    description = Column(Text, comment='权限描述')
    status = Column(Boolean, default=True, comment='状态')

    # 与角色的多对多关系
    roles = relationship('RoleModel',
                         secondary='sys_role_permissions',
                         back_populates='permissions')

    def __repr__(self):
        return f"<Permission(id={self.id}, name={self.name})>"
