from sqlalchemy import Column, Integer, DateTime, ForeignKey
from .base_model import BaseModel, CreateModel, UpdateModel, DeleteModel


class WrongQuestionModel(BaseModel, CreateModel, UpdateModel, DeleteModel):
    """
    错题模型
    对应数据库表: wrong_questions
    """
    __tablename__ = 'wrong_questions'

    user_id = Column(Integer,
                     ForeignKey('users.id'),
                     nullable=False,
                     comment='用户ID')
    question_id = Column(Integer,
                         ForeignKey('questions.id'),
                         nullable=False,
                         comment='题目ID')
    exam_id = Column(Integer, ForeignKey('exams.id'), comment='考试ID')
    exercise_id = Column(Integer, ForeignKey('exercises.id'), comment='练习ID')
    wrong_count = Column(Integer, nullable=False, default=1, comment='错误次数')
    last_wrong_time = Column(DateTime, nullable=False, comment='最后错误时间')

    def __repr__(self):
        return f"<WrongQuestion(id={self.id}, user_id={self.user_id}, question_id={self.question_id})>"
