from typing import Optional
from sqlalchemy.orm import Session
from ..models.status_model import StatusModel
from .base_store import BaseStore


class StatusStore(BaseStore[StatusModel]):
    """
    状态存储类，继承自BaseStore
    提供状态相关的特定操作
    """

    def __init__(self, db: Session):
        super().__init__(db, StatusModel)

    def get_by_type(self, type: str) -> Optional[StatusModel]:
        """根据类型获取状态"""
        return self.db.query(
            self.model).filter(self.model.type == type).first()

    def get_all_by_status(self, status: int) -> list[StatusModel]:
        """根据状态值获取所有状态"""
        return self.db.query(
            self.model).filter(self.model.status == status).all()

    def get_all_by_sort(self) -> list[StatusModel]:
        """根据排序获取所有状态"""
        return self.db.query(self.model).order_by(self.model.sort).all()
